@@ -102,29 +102,44 @@ def get_prog():
         return '<prog>'
         
 class Pager(object):
-    """enable paging for multiple writes"""
-    
+    """enable paging for multiple writes
+
+    see http://svn.python.org/view/python/branches/release25-maint/Lib/pydoc.py?view=markup
+    (getpager()) for handling different circumstances or platforms
+    """
+
     def __init__(self):
         self.proc = None
-        
+        self.file = sys.stdout # ultimate fallback
+        self.cmd = ''
+
         if hasattr(sys.stdout, 'isatty') and sys.stdout.isatty():
-            pager = 'more -EMR'
-            self.proc = subprocess.Popen([pager], shell=True, 
-                stdin=subprocess.PIPE, stderr=subprocess.PIPE)
-            self.file = self.proc.stdin
-        else:
-            self.file = sys.stdout
+            pager_commands = ['more -EMR', 'more', 'less -MR', 'less']
+            for cmd in pager_commands:
+                if hasattr(os, 'system') and \
+                              os.system('(%s) 2>/dev/null' % cmd) == 0:
+                    self.proc = subprocess.Popen([cmd], shell=True, 
+                        stdin=subprocess.PIPE, stderr=subprocess.PIPE)
+                    self.file = self.proc.stdin
+                    self.cmd = cmd
+                    break
 
     def write(self, text=""):
         try:
             self.file.write("%s\n" % text)
         except:
-            # in case the pager is not available
+            # in case the pager cmd fails unexpectedly
             self.file = sys.stdout
-            self.write(text) # known issue: sometimes, does not show text on first write
-        
-    def close(self): 
+            self.file.write("%s\n" % text)
+
+    def close(self):
+        if 'less' in self.cmd:
+            self.write("press q to quit")
         if self.proc: 
-            self.file.close() 
-            self.proc.wait()
+            self.file.close()
+            try:
+                self.proc.wait()
+            except KeyboardInterrupt:
+                # TODO: should kill the self.proc here gracefully
+                sys.exit(0) # close silently no matter what
 
